#
# spec file for package perl-Test-Strict
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Test-Strict
Name:           perl-Test-Strict
Version:        0.540.0
Release:        1.2
# 0.54 -> normalize -> 0.540.0
%define cpan_version 0.54
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Check syntax, presence of use strict; and test coverage
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MA/MANWAR/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.64
BuildRequires:  perl(IO::Scalar)
BuildRequires:  perl(Test::More) >= 1.00
Provides:       perl(Test::Strict) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
The most basic test one can write is "does it compile ?". This module tests
if the code compiles and play nice with Test::Simple modules.

Another good practice this module can test is to "use strict;" in all perl
files.

By setting a minimum test coverage through 'all_cover_ok()', a code author
can ensure his code is tested above a preset level of _kwality_ throughout
the development cycle.

Along with Test::Pod, this module can provide the first tests to setup for
a module author.

This module should be able to run under the -T flag for perl >= 5.6. All
paths are untainted with the following pattern: 'qr|^([-+@\w./:\\]+)$|'
controlled by '$Test::Strict::UNTAINT_PATTERN'.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
# generated by find-debuginfo in current Tumblweeed, not sure why or how to disable that
rm -f debugfiles.list debuglinks.list debugsourcefiles.list debugsources.list elfbins.list
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Sat Apr 19 2025 Tina Müller <tina.mueller@suse.com>
- Remove files generated by find-debuginfo before testing; it was
  breaking t/93-checkmanifest.t, detecting unexpected files
* Tue Sep 24 2024 Tina Müller <tina.mueller@suse.com>
- Remove test-perl-5.38.patch (fixed upstream)
* Thu Jul 25 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.540.0 (0.54)
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.54  2024-07-24 17:45:00 MANWAR
  - Fix skipping of .git, .svn, and CVS directories, thanks @haarg.
  0.53  2024-07-22 13:30:00 MANWAR
  - Don't simultaneously test -c and -v switches (PR #33), thanks @jkeenan.
  - Fixed manifest check (PR #35), thanks @haarg.
* Thu Aug  3 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add test-perl-5.38.patch: Don't simultaneously test -c and -v
  switches. Patch based on
  https://patch-diff.githubusercontent.com/raw/manwar/Test-Strict/pull/33.patch.
* Tue Jun 18 2019 Stephan Kulow <coolo@please-enter-an-email-address>
- updated to 0.52
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.52  2019-06-16 10:10:00 MANWAR
  - Applied patch provided by Matthew (Issue #25).
* Sun Jun 16 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.51
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.51  2019-06-15 06:30:00 MANWAR
  - Now ignores .git folder (Issue #26).
* Sat Jun 15 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.50
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.50  2019-06-14 15:30:00 MANWAR
  - Added Test::Roo::Role to the list (Issue #29).
* Fri Jun 14 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.49
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.49  2019-06-13 12:20:00 MANWAR
  - Fixed CPANTS issue (main_module_version_matches_dist_version).
* Thu May 30 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.48
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.48  2019-05-29 11:00:00 MANWAR
  - Added Test::Most to modules with strictures, #27 @robrwo
* Tue Jul 17 2018 coolo@suse.com
- updated to 0.47
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.47  2018-07-07 18:00:00 MANWAR
  - Upgraded version.
* Sat Jul  7 2018 coolo@suse.com
- updated to 0.46
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.46  2018-07-06 15:55:00 MANWAR
  - Patched issue #24 raised by @robrwo.
* Sun Feb 25 2018 coolo@suse.com
- updated to 0.45
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.45  2018-02-22 16:45:00 MANWAR
  - Revisited to address issue #17, (Devel::Cover no longer prereq).
  0.44  2018-02-21 19:20:00 MANWAR
  - Added key 'clean' and 'dist' to Makefile.PL script.
* Wed Feb 21 2018 coolo@suse.com
- updated to 0.43
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.43  2018-02-20 15:00:00 MANWAR
  - Bumped the version.
  0.42  2018-02-20 13:00:00 MANWAR
  - Addressed issue #17, (Devel::Cover no longer prereq).
* Mon Feb 12 2018 coolo@suse.com
- updated to 0.41
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.41  2018-02-09 12:30:00 MANWAR
  - Merged pull request #23, thanks @arc.
* Thu Nov 30 2017 coolo@suse.com
- updated to 0.40
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.40  2017-11-29 13:00:00 MANWAR
  - Merged pull request #22, thanks @cpansprout.
* Sat Dec  3 2016 coolo@suse.com
- updated to 0.39
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.39  2016-12-02 12:10:00 MANWAR
  - Merged pull request #21, thanks @arc.
* Fri Dec  2 2016 coolo@suse.com
- updated to 0.38
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.38  2016-12-01 12:50:00 MANWAR
  - Merged pull request #20, thanks @tomhukins.
* Sun Jun 12 2016 coolo@suse.com
- updated to 0.37
  see /usr/share/doc/packages/perl-Test-Strict/Changes
* Tue Jan 19 2016 coolo@suse.com
- updated to 0.36
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.36  2016-01-17 02:10:00 MANWAR
  - Fixed issue RT# 55112 (svn directories incorrectly filtered out).
  0.35  2016-01-16 08:45:00 MANWAR
  - Fixed Github issue #16.
* Sun Nov 15 2015 coolo@suse.com
- updated to 0.34
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.34  2015-11-15 08:50:00 MANWAR
  - Added key 'provides' to the Makefile.PL script.
* Sat Nov 14 2015 coolo@suse.com
- updated to 0.33
  see /usr/share/doc/packages/perl-Test-Strict/Changes
* Mon Nov  9 2015 coolo@suse.com
- updated to 0.32
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.32 2015-11-03 10:10:00 MANWAR
  - Added LICENSE file.
  - Added standard unit test script (t/00-load.t).
* Thu Oct 29 2015 coolo@suse.com
- updated to 0.31
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.31 2015-10-27 10:35:00 MANWAR
  - Upgraded the min perl version to 5.006 as proposed by Perl::MinimumVersion.
  - Added MIN_PERL_VERSION to the Makefile.PL script.
  - Updated unit test script t/02fail.t to comply with perl 5.006.
* Sat Oct 24 2015 coolo@suse.com
- updated to 0.30
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.30 2015-10-24
  - Tidied up Makefile.PL script.
  - Removed the executable attributes from some of the unit test script.
  0.29 2015-10-19
  - Updated link to github repository in the Makefile.PL script
  - Updated bugtracker link in the Makefile.PL script.
  - Updated x_contributors list in the Makefile.PL script
  - Updated link to github repository in the pod document of Test::Strict package.
  - Updated MAINTAINER section in the pod document of Test::Strict package.
* Sun Oct  4 2015 coolo@suse.com
- updated to 0.28
  see /usr/share/doc/packages/perl-Test-Strict/Changes
  0.28 2015-10-02
  - Make syntax_ok check modules without '::' in their names (Petr Šabata)
* Thu Apr 16 2015 coolo@suse.com
- updated to 0.27
  see /usr/share/doc/packages/perl-Test-Strict/Changes
* Sun May  1 2011 coolo@opensuse.org
- initial package 0.14
  * created by cpanspec 1.78.04
